@@ -10,8 +10,6 @@ from scipy.optimize import minimize, differential_evolution, fmin_l_bfgs_b
 from multiprocessing import Pool
 from warnings import warn
 from copy import copy
-from typing import Type
-from collections.abc import Sequence
 
 import matplotlib.pyplot as plt
 
@@ -90,8 +88,8 @@ class GpRegressor:
         y_err: ndarray = None,
         y_cov: ndarray = None,
         hyperpars: ndarray = None,
-        kernel: Type[CovarianceFunction] = SquaredExponential,
-        mean: Type[MeanFunction] = ConstantMean,
+        kernel: CovarianceFunction = SquaredExponential,
+        mean: MeanFunction = ConstantMean,
         cross_val: bool = False,
         optimizer: str = "bfgs",
         n_processes: int = 1,
@@ -503,11 +501,10 @@ class GpRegressor:
         K_xx, grad_K = self.cov.covariance_and_gradients(theta[self.cov_slice])
         K_xx += self.sig
         mu, grad_mu = self.mean.mean_and_gradients(theta[self.mean_slice])
-        # use the cholesky decomp to get the covariance inverse
+        # use the Cholesky decomp to get the covariance inverse
         L = cholesky(K_xx)
         iK = solve_triangular(L, eye(L.shape[0]), lower=True)
         iK = iK.T @ iK
-        # Use the Cholesky decomposition of the covariance to find its inverse
         alpha = iK.dot(self.y - mu)
         var = 1.0 / diag(iK)
         LOO = -0.5 * (var * alpha**2 + log(var)).sum()
@@ -611,8 +608,15 @@ class GpRegressor:
         solution = sorted(results, key=lambda x: x[1])[0][0]
         return solution
 
+    def __str__(self):
+        L_max = max([len(lb) for lb in self.hyperpar_labels])
+        strings = ["\n>>> [ GpRegressor hyperparameters ]\n"]
+        for lb, val in zip(self.hyperpar_labels, self.hyperpars):
+            strings.append(" " * (L_max - len(lb)) + f"{lb} = {val:.4}\n")
+        return "".join(strings)
 
-class MarginalisedGpRegressor(object):
+
+class MarginalisedGpRegressor:
     def __init__(
         self,
         x,
@@ -724,8 +728,8 @@ class GpOptimiser:
         bounds: Sequence,
         y_err: ndarray = None,
         hyperpars: ndarray = None,
-        kernel: Type[CovarianceFunction] = SquaredExponential,
-        mean: Type[MeanFunction] = ConstantMean,
+        kernel: CovarianceFunction = SquaredExponential,
+        mean: MeanFunction = ConstantMean,
         cross_val: bool = False,
         acquisition=ExpectedImprovement,
         optimizer: str = "bfgs",
@@ -971,8 +975,8 @@ class GpLinearInverter:
         y_err: ndarray,
         model_matrix: ndarray,
         parameter_spatial_positions: ndarray,
-        prior_covariance_function: Type[CovarianceFunction] = SquaredExponential,
-        prior_mean_function: Type[MeanFunction] = ConstantMean,
+        prior_covariance_function: CovarianceFunction = SquaredExponential,
+        prior_mean_function: MeanFunction = ConstantMean,
     ):
         if model_matrix.ndim != 2:
             raise ValueError(
